@@ -42,9 +42,9 @@ copyright = '2018, Bob Ippolito'
 # other places throughout the built documents.
 #
 # The short X.Y version.
-version = '3.14'
+version = '3.16'
 # The full version, including alpha/beta/rc tags.
-release = '3.14.0'
+release = '3.16.0'
 
 # There are two options for replacing |today|: either, you set today to some
 # non-false value, then it is used:
@@ -83,7 +83,7 @@ pygments_style = 'sphinx'
 # The style sheet to use for HTML and HTML Help pages. A file of that name
 # must exist either in Sphinx' static/ path, or in one of the custom paths
 # given in html_static_path.
-html_style = 'default.css'
+#html_style = 'default.css'
 
 # The name for this set of Sphinx documents.  If None, it defaults to
 # "<project> v<release> documentation".
